Documentation
¶
Overview ¶
Copyright (c) 2014-2019 Cesanta Software Limited All rights reserved
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FlashOpts ¶
type FlashOpts struct {
ControlPort string
DataPort string
ROMBaudRate uint
FlasherBaudRate uint
InvertedControlLines bool
FlashParams string
EraseChip bool
EnableCompression bool
MinimizeWrites bool
BootFirmware bool
ESP32EncryptionKeyFile string
ESP32FlashCryptConf uint32
KeepFS bool
NoVerify bool
}
type RegReaderWriter ¶
Click to show internal directories.
Click to hide internal directories.