pflagenv

package
v0.0.0-...-b44964e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Copyright (c) 2014-2019 Cesanta Software Limited All rights reserved

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Parse

func Parse(envPrefix string)

The same as ParseFlagSet, but operates on a default FlagSet: pflag.CommandLine

func ParseFlagSet

func ParseFlagSet(fs *pflag.FlagSet, envPrefix string)

ParseFlagSet iterates through all non-set flags in the given FlagSet, checks if there is an environment variable with the uppercased flag name prepended with the given envPrefix, and if so, sets flag value to the environment variable value.

It should be called after Parse is called for the given FlagSet.

Types

This section is empty.

Jump to